.. _data:

delu.utils.data
===============

.. currentmodule:: delu.utils.data

.. automodule:: delu.utils.data

.. autosummary::
    :nosignatures:
    :toctree: generated
    :template: class.rst

    Enumerate
    IndexDataset
